@@ -1,9 +1,11 @@
 module.exports = {
-  packagerConfig: {},
+  packagerConfig: {
+    icon: './shiny/assets/icon/icon'
+  },
   rebuildConfig: {},
   makers: [
     {
       name: '@electron-forge/maker-zip'
     }
-  ]
+  ],
 };
